@@ -341,8 +341,8 @@ class CAM(object):
                 while not self._log_queue[msg['task_id']].empty():
                     txt = self._log_queue[msg['task_id']].get_nowait()
                     self._log[msg['task_id']] += txt
-                lines = self._log[msg['task_id']].strip().split('\n')
-                lines = [lines[i] for i in range(len(lines)) if SequenceMatcher(None, lines[i - 1], lines[i]).ratio() < 0.9 or i == 0 or i == len(lines) - 1]
+                lines = self._log[msg['task_id']].strip().replace("\r", "\n").split('\n')
+                lines = [lines[i] for i in range(len(lines)) if (SequenceMatcher(None, lines[i - 1], lines[i]).ratio() < 0.8 or i == 0 or i == len(lines) - 1) and (len(lines[i]) > 0)]
                 maxlen = 600
                 if len(lines) < maxlen:
                     txt = "\n".join(lines)
